package PureMessage::Service::blockerd;

use strict;
use warnings;
use base 'PureMessage::Service';
use PureMessage::Blocklist::Service qw( blockerd_is_running        blockerd_start
                                        blockerd_stop              blockerd_status
                                        blockerd_restart
                                        blocklist_service_enabled  blocklist_enable
                                        blocklist_disable
                                      );

sub Available {
    my $class = shift;
    return ($class->new(name => 'Blocker'));
}

# This should be exported by the base class as each service will
# want to use this.
sub _bg {
    my $pid = fork();
    die "Can't fork: $!" unless defined $pid;
    return $pid if $pid;
    
    open(STDIN, "</dev/null");
    open(STDOUT, ">/dev/null");
    open(STDERR, ">/dev/null");
    return 0;
}

sub start {
    my ($self, %opts) = @_;
    if ($opts{bg}) {
        if (my $pid = _bg()) {
            return $pid;
        }
    }

    blockerd_start();
    
    exit if $opts{bg};
}

sub stop {
    my ($self, %opts) = @_;
    if ($opts{bg}) {
        if (my $pid = _bg()) {
            return $pid;
        }
    }
    
    blockerd_stop();
    
    exit if $opts{bg};
}

sub restart {
    my ($self, %opts) = @_;
    if ($opts{bg}) {
        if (my $pid = _bg()) {
            return $pid;
        }
    }
    
    blockerd_restart();
    
    exit if $opts{bg};
}

sub status {
    my $self = shift;
    my $info = blockerd_status();
    
    $info->{summary}  = "PureMessage IP Blocker";
    $info->{summary} .= ", port " . $info->{'port'};
    
    return $info;
}

sub running {
    my $self = shift;

    return blockerd_is_running();
}

sub enable {
    my $self = shift;
    
    return blocklist_enable();

}

sub disable {
    my $self = shift;
    
    return blocklist_disable();
}

sub service_status {
    my $self = shift;
    
    return blocklist_service_enabled();
}

1;
